@@ -1,10 +1,15 @@
-from numpy import asarray, empty
+from numpy import asarray, empty, float64
 from numpy.random import RandomState
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_equal
 
 from liknorm import LikNormMachine
 
 
+def test_sizeof_double():
+    from liknorm.machine_ffi import ffi
+    assert_equal(ffi.sizeof("double"), 8)
+
+
 def test_liknormmachine():
     machine = LikNormMachine('binomial', 500)
     random = RandomState(0)
@@ -19,9 +24,9 @@ def test_liknormmachine():
     ceta = random.rand(5)
     ctau = random.randn(5) * ceta
 
-    lmom0 = empty(5)
-    hmu = empty(5)
-    hvar = empty(5)
+    lmom0 = empty(5, dtype=float64)
+    hmu = empty(5, dtype=float64)
+    hvar = empty(5, dtype=float64)
 
     machine.moments(y, ceta, ctau,
                     {'log_zeroth': lmom0,
